@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Get XML.
 has xml => (
@@ -166,7 +166,7 @@ For more information about Bucharest Map, click L<here|https://en.wikipedia.org/
 	 'callback_node' => \&node_color_without_label,
 	 'driver' => 'neato',
 	 'tube' => $obj,
- ); 
+ );
 
  # Get graph to file.
  $g->graph('Bucharest.png');
@@ -195,11 +195,15 @@ L<namespace::clean>.
 =head1 SEE ALSO
 
 L<Map::Tube>,
+L<Map::Tube::Graph>,
 L<Map::Tube::GraphViz>,
-L<Map::Tube::Text::Table>.
+L<Map::Tube::Plugin::Graph>,
+L<Map::Tube::Text::Table>,
+L<Task::Map::Tube>.
 
 L<Map::Tube::Barcelona>,
 L<Map::Tube::Berlin>,
+L<Map::Tube::Budapest>,
 L<Map::Tube::Delhi>,
 L<Map::Tube::Dnipropetrovsk>,
 L<Map::Tube::Kazan>,
@@ -208,8 +212,9 @@ L<Map::Tube::Kiev>,
 L<Map::Tube::London>,
 L<Map::Tube::Minsk>,
 L<Map::Tube::Moscow>,
-L<Map::Tube::Novosibirsk>,
 L<Map::Tube::NYC>,
+L<Map::Tube::Nanjing>,
+L<Map::Tube::Novosibirsk>,
 L<Map::Tube::Prague>,
 L<Map::Tube::SaintPetersburg>,
 L<Map::Tube::Samara>,
@@ -232,12 +237,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014 Michal Špaček
+ © 2014-2015 Michal Špaček
  Artistic License
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
